<!DOCTYPE html>
<html>
<head>
    <title>{% block title %}Go Links{% endblock %}</title>
    <style>
        body {
            font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, sans-serif;
            max-width: {% block max_width %}800px{% endblock %};
            margin: {% block margin %}50px auto{% endblock %};
            padding: 20px;
            {% block body_styles %}background: #f5f5f5;{% endblock %}
        }
        h1 {
            color: {% block h1_color %}#333{% endblock %};
            {% block h1_styles %}
            border-bottom: 2px solid #007bff;
            padding-bottom: 10px;
            {% endblock %}
        }
        {% block extra_styles %}{% endblock %}
    </style>
</head>
<body>
    {% block content %}{% endblock %}
</body>
</html>